<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryRef" :inline="true" v-show="showSearch" label-width="68px">
      <el-form-item label="事件描述" prop="description">
        <el-input
          v-model="queryParams.description"
          placeholder="请输入事件描述"
          clearable
          @keyup.enter="handleQuery"
        />
      </el-form-item>
<!--      <el-form-item label="持续时长" prop="duration">-->
<!--        <el-input-->
<!--          v-model="queryParams.duration"-->
<!--          placeholder="请输入持续时长"-->
<!--          clearable-->
<!--          @keyup.enter="handleQuery"-->
<!--        />-->
<!--      </el-form-item>-->
<!--      <el-form-item label="事件开始日期" prop="startDate">-->
<!--        <el-date-picker clearable-->
<!--          v-model="queryParams.startDate"-->
<!--          type="date"-->
<!--          value-format="YYYY-MM-DD"-->
<!--          placeholder="请选择事件开始日期">-->
<!--        </el-date-picker>-->
<!--      </el-form-item>-->
<!--      <el-form-item label="事件结束日期" prop="endDate">-->
<!--        <el-date-picker clearable-->
<!--          v-model="queryParams.endDate"-->
<!--          type="date"-->
<!--          value-format="YYYY-MM-DD"-->
<!--          placeholder="请选择事件结束日期">-->
<!--        </el-date-picker>-->
<!--      </el-form-item>-->
<!--      <el-form-item label="事件开始时间" prop="startTime">-->
<!--        <el-date-picker clearable-->
<!--          v-model="queryParams.startTime"-->
<!--          type="date"-->
<!--          value-format="YYYY-MM-DD"-->
<!--          placeholder="请选择事件开始时间">-->
<!--        </el-date-picker>-->
<!--      </el-form-item>-->
<!--      <el-form-item label="事件结束时间" prop="endTime">-->
<!--        <el-date-picker clearable-->
<!--          v-model="queryParams.endTime"-->
<!--          type="date"-->
<!--          value-format="YYYY-MM-DD"-->
<!--          placeholder="请选择事件结束时间">-->
<!--        </el-date-picker>-->
<!--      </el-form-item>-->
      <el-form-item>
        <el-button type="primary" icon="Search" @click="handleQuery">搜索</el-button>
        <el-button icon="Refresh" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="Plus"
          @click="handleAdd"
          v-hasPermi="['core:event:add']"
        >新增</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="success"
          plain
          icon="Edit"
          :disabled="single"
          @click="handleUpdate"
          v-hasPermi="['core:event:edit']"
        >修改</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="danger"
          plain
          icon="Delete"
          :disabled="multiple"
          @click="handleDelete"
          v-hasPermi="['core:event:remove']"
        >删除</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="warning"
          plain
          icon="Download"
          @click="handleExport"
          v-hasPermi="['core:event:export']"
        >导出</el-button>
      </el-col>
      <right-toolbar v-model:showSearch="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <HxlhTable
        style="width: 100%"
        :columns="columns"
        :data="eventList"
        :loading="loading"
        :height="height"
        :page="page"
        @changePageNo="changePageNo"
        @changePageSize="changePageSize"
        @on-checkbox="handleCheckboxChange"
    >

      <template #buttons="{row}">
        <vxe-button mode="text" @click="handleUpdate(row)" v-hasPermi="['plant:edit']" >修改</vxe-button>
      </template>
    </HxlhTable>

    <!-- 添加或修改事件管理对话框 -->
    <el-dialog :title="title" v-model="open" width="700px" append-to-body>
      <el-form ref="eventRef" :model="form" :rules="rules" label-width="120px">
        <el-form-item label="事件描述" prop="description">
          <el-input v-model="form.description" placeholder="请输入事件描述" />
        </el-form-item>
        <el-form-item label="事件开始日期" prop="startDate">
          <el-date-picker clearable
                          v-model="form.startDateTime"
                          type="datetime"
                          format="YYYY-MM-DD HH:mm"
                          date-format="YYYY-MM-DD"
                          time-format="hh:mm"
                          value-format="YYYY-MM-DD HH:mm"
                          placeholder="请选择事件开始日期">
          </el-date-picker>
        </el-form-item>
        <el-form-item label="事件结束日期" prop="endDate">
          <el-date-picker clearable
                          v-model="form.endDateTime"
                          type="datetime"
                          format="YYYY-MM-DD HH:mm"
                          date-format="YYYY-MM-DD"
                          time-format="hh:mm"
                          value-format="YYYY-MM-DD HH:mm"
                          placeholder="请选择事件结束日期">
          </el-date-picker>
        </el-form-item>
        <el-form-item label="持续时长" prop="duration">
          <el-input type="number" v-model="form.duration" placeholder="请输入持续时长" style="width: 150px" min="0"/>&nbsp;小时
        </el-form-item>
        <el-form-item label="适用工厂" prop="applicableFactory">
          <el-select v-model="form.applicableFactory" placeholder="请选择适用工厂" @change="changePlant($event)">
            <el-option
                v-for="plant in plantList"
                :key="plant.id"
                :label="plant.plantName"
                :value="plant.plantCode">
            </el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="适用车间" prop="applicableWorkshop">
          <el-select v-model="form.applicableWorkshop" placeholder="请选择适用车间" filterable>
            <el-option
                v-for="shop in shopList"
                :key="shop.id"
                :label="shop.shopName"
                :value="shop.id">
            </el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="适用工序" prop="applicableProcess">
          <el-select v-model="form.applicableProcess" placeholder="请选择适用工序" filterable>
            <el-option
                v-for="process in processList"
                :key="process.id"
                :label="process.processName"
                :value="process.processName">
            </el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="适用日历" prop="applicableCalendar">
          <el-select v-model="form.applicableCalendar" placeholder="请选择适用日历">
            <el-option
                v-for="calendar in calendarList"
                :key="calendar.id"
                :label="calendar.description"
                :value="calendar.id">
            </el-option>
          </el-select>
        </el-form-item>
      </el-form>
      <template #footer>
        <div class="dialog-footer">
          <el-button type="primary" @click="submitForm">确 定</el-button>
          <el-button @click="cancel">取 消</el-button>
        </div>
      </template>
    </el-dialog>
  </div>
</template>

<script setup name="Event">
import { listEvent, getEvent, delEvent, addEvent, updateEvent } from "@/api/basicData/event";
import { listAll_plant } from "@/api/basicData/plant";
import { listAll_shop, listAps_shop } from "@/api/basicData/shop";
import { selectProcessNameList } from "@/api/basicData/processRoute.js";
import HxlhTable from '@/components/HxlhTable'
import axios from "axios";
import {listAll_calendar} from "@/api/basicData/calendar.js";

const { proxy } = getCurrentInstance();

const eventList = ref([]);
const open = ref(false);
const loading = ref(true);
const showSearch = ref(true);
const ids = ref([]);
const single = ref(true);
const multiple = ref(true);
const total = ref(0);
const title = ref("");
const plantList = ref([]);
const shopList = ref([]);
const allShopList = ref([]);
const processList = ref([]);
const calendarList = ref([]);

const height = ref(document.documentElement.clientHeight - 230 + "px;")

// 多选框选中数据
const handleCheckboxChange = (data) => {
  ids.value = data.records.map(item => item.id);
  single.value = data.records.length !== 1;
  multiple.value = !data.records.length;
};

// 分页属性
const page = ref({
  total: 0,
  current: 1,
  size: 10
});
// 表格配置
const columns = ref([
  { type: 'checkbox', width: 60, align:"center"},
  { type: 'seq', title: '序号', width: 60, align: 'center' },
  {
    title: '事件描述',
    field: 'description',
    width: 150,
    align: 'center'
  },
  {
    title: '持续时长',
    field: 'duration',
    width: 150,
    align: 'center'
  },
  {
    title: '事件开始日期',
    field: 'startDate',
    width: 150,
    align: 'center'
  },
  {
    title: '事件结束日期',
    field: 'endDate',
    width: 150,
    align: 'center'
  },
  {
    title: '事件开始时间',
    field: 'startTime',
    width: 150,
    align: 'center'
  },
  {
    title: '事件结束时间',
    field: 'endTime',
    width: 150,
    align: 'center'
  },
  {
    title: '适用工厂',
    field: 'applicableFactory',
    width: 150,
    align: 'center',
    formatter: (({ cellValue, row, column }) => {
      if (cellValue) {
        for(let i=0;i<plantList.value.length;i++){
          if(cellValue===plantList.value[i].plantCode){
            return plantList.value[i].plantName
          }
        }
      }
      return '';
    })
  },
  {
    title: '适用车间',
    field: 'applicableWorkshop',
    width: 150,
    align: 'center',
    formatter: (({ cellValue, row, column }) => {
      if (cellValue) {
        for(let i=0;i<allShopList.value.length;i++){
          if(cellValue===allShopList.value[i].id){
            return allShopList.value[i].shopName
          }
        }
      }
      return '';
    })
  },
  {
    title: '适用工序',
    field: 'applicableProcess',
    width: 150,
    align: 'center'
  },
  {
    title: '适用日历',
    field: 'applicableCalendar',
    width: 150,
    align: 'center'
  },
  { title: '操作', width: 100, fixed:"right", slots: { default: 'buttons' }, align: 'center' }
]);

const data = reactive({
  form: {},
  queryParams: {
    pageNum: 1,
    pageSize: 10,
    description: null,
    duration: null,
    startDate: null,
    endDate: null,
    startTime: null,
    endTime: null,
    applicableFactory: null,
    applicableWorkshop: null,
    applicableProcess: null,
    applicableCalendar: null,
    startDateTime: null,
    endDateTime: null
  },
  rules: {
    description: [
      { required: true, message: "事件描述不能为空", trigger: "blur" }
    ],
    duration: [
      { required: true, message: "持续时长不能为空", trigger: "blur" }
    ],
    startDateTime: [
      { required: true, message: "事件开始日期不能为空", trigger: "blur" }
    ],
    endDateTime: [
      { required: true, message: "事件结束日期不能为空", trigger: "blur" }
    ],
    applicableFactory: [
      { required: true, message: "适用工厂不能为空", trigger: "change" }
    ],
    applicableWorkshop: [
      { required: true, message: "适用车间不能为空", trigger: "change" }
    ],
    applicableProcess: [
      { required: true, message: "适用工序不能为空", trigger: "change" }
    ],
    applicableCalendar: [
      { required: true, message: "适用日历不能为空", trigger: "change" }
    ],
  }
});

const { queryParams, form, rules } = toRefs(data);

/** 查询事件管理列表 */
function getList() {
  axios.all([
    /** 查询事件列表 **/
    listEvent(queryParams.value),
    /** 查询工厂列表 */
    listAll_plant({}),
    /** 查询车间列表 */
    listAll_shop({}),
    listAll_calendar({})
  ])
  .then(axios.spread((response1, response2, response3, response4) => {
    eventList.value = response1.rows;
    plantList.value = response2.data;
    allShopList.value = response3.data;
    calendarList.value = response4.data;
    total.value = response1.total;
    loading.value = false;
  }))
  .catch(error => {
    console.error('请求出错:', error);
  });


  loading.value = true;
  listEvent(queryParams.value).then(response => {

    loading.value = false;
  });
}

// 取消按钮
function cancel() {
  open.value = false;
  reset();
}

// 表单重置
function reset() {
  form.value = {
    id: null,
    description: null,
    duration: null,
    startDate: null,
    endDate: null,
    startTime: null,
    endTime: null,
    applicableFactory: null,
    applicableWorkshop: null,
    applicableProcess: null,
    applicableCalendar: null,
    createBy: null,
    createTime: null,
    updateBy: null,
    updateTime: null,
    startDateTime: null,
    endDateTime: null
  };
  proxy.resetForm("eventRef");
}

/** 搜索按钮操作 */
function handleQuery() {
  queryParams.value.pageNum = 1;
  getList();
}

/** 重置按钮操作 */
function resetQuery() {
  proxy.resetForm("queryRef");
  handleQuery();
}

// 多选框选中数据
function handleSelectionChange(selection) {
  ids.value = selection.map(item => item.id);
  single.value = selection.length != 1;
  multiple.value = !selection.length;
}

/** 新增按钮操作 */
function handleAdd() {
  reset();
  open.value = true;
  title.value = "新增事件";
}

/** 修改按钮操作 */
function handleUpdate(row) {
  reset();
  const _id = row.id || ids.value
  getEvent(_id).then(response => {
    form.value = response.data;
    form.value.startDateTime = form.value.startDate + " " + form.value.startTime;
    form.value.endDateTime = form.value.endDate + " " + form.value.endTime;
    changePlant(form.value.applicableFactory);
    open.value = true;
    title.value = "修改事件管理";
  });
}

/** 提交按钮 */
function submitForm() {
  proxy.$refs["eventRef"].validate(valid => {
    if (valid) {
      form.value.startDate = form.value.startDateTime.split(" ")[0];
      form.value.endDate = form.value.endDateTime.split(" ")[0];
      form.value.startTime = form.value.startDateTime.split(" ")[1];
      form.value.endTime = form.value.endDateTime.split(" ")[1];
      if (form.value.id != null) {
        updateEvent(form.value).then(response => {
          proxy.$modal.msgSuccess("修改成功");
          open.value = false;
          getList();
        });
      } else {
        addEvent(form.value).then(response => {
          proxy.$modal.msgSuccess("新增成功");
          open.value = false;
          getList();
        });
      }
    }
  });
}

/** 删除按钮操作 */
function handleDelete(row) {
  const _ids = row.id || ids.value;
  proxy.$modal.confirm('是否确认删除事件管理编号为"' + _ids + '"的数据项？').then(function() {
    return delEvent(_ids);
  }).then(() => {
    getList();
    proxy.$modal.msgSuccess("删除成功");
  }).catch(() => {});
}

/** 导出按钮操作 */
function handleExport() {
  proxy.download('/aps/event/export', {
    ...queryParams.value
  }, `event_${new Date().getTime()}.xlsx`)
}

/** 选择工厂后事件 加载车间 和 工序 **/
function changePlant(plant){
  listAps_shop({"plantCode": plant}).then(response => {
    shopList.value = response.rows;
  })
  selectProcessNameList({"orgCode": plant}).then(response => {
    processList.value = response.rows;
  })
}

function changePageNo(currentPage) {
  queryParams.value.pageNum = currentPage;
  page.value.current = currentPage;
  getList();
}

function changePageSize(pageSize) {
  page.value.current = 1;
  queryParams.value.pageNum = 1;
  queryParams.value.pageSize = pageSize;
  getList();
}

/** 初始化数据 **/
onMounted(()=>{})

getList();
</script>
